@@ -157,7 +157,7 @@ class Imdb(object):
         r = requests.get(url, headers={'User-Agent': '''Mozilla/5.0
         (iPhone; U; CPU iPhone OS 4_1 like Mac OS X; en-us)
         AppleWebKit/532.9 (KHTML, like Gecko) Version/4.0.5 Mobile/8B5097d Safari/6531.22.7'''})
-        return json.loads(r.text)
+        return json.loads(r.content)
 
 
 class Person(object):
